@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AgentTicketService;
@@ -11,10 +11,13 @@ package Kernel::Modules::AgentTicketService;
 use strict;
 use warnings;
 
-use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language qw(Translatable);
+use Kernel::System::DynamicField;
+use Kernel::System::JSON;
+use Kernel::System::Lock;
+use Kernel::System::Service;
+use Kernel::System::State;
 
-our $ObjectManagerDisabled = 1;
+use Kernel::System::VariableCheck qw(:all);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -26,68 +29,80 @@ sub new {
     # set debug
     $Self->{Debug} = 0;
 
+    # check all needed objects
+    for my $Needed (
+        qw(ParamObject DBObject QueueObject LayoutObject ConfigObject LogObject UserObject)
+        )
+    {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
+        }
+    }
+
+    $Self->{Config} = $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}");
+
+    # some new objects
+    $Self->{JSONObject}         = Kernel::System::JSON->new( %{$Self} );
+    $Self->{StateObject}        = Kernel::System::State->new(%Param);
+    $Self->{LockObject}         = Kernel::System::Lock->new(%Param);
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{ServiceObject}      = Kernel::System::Service->new(%Param);
+
+    # get config data
+    $Self->{CustomService} = $Self->{ConfigObject}->Get('Ticket::CustomService') || 'My Services';
+
+    # get params
+    $Self->{ViewAll}   = $Self->{ParamObject}->GetParam( Param => 'ViewAll' )   || 0;
+    $Self->{Start}     = $Self->{ParamObject}->GetParam( Param => 'StartHit' )  || 1;
+    $Self->{Filter}    = $Self->{ParamObject}->GetParam( Param => 'Filter' )    || 'Unlocked';
+    $Self->{View}      = $Self->{ParamObject}->GetParam( Param => 'View' )      || '';
+    $Self->{ServiceID} = $Self->{ParamObject}->GetParam( Param => 'ServiceID' ) || 0;
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    # get needed objects
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $ParamObject  = $Kernel::OM->Get('Kernel::System::Web::Request');
-
     # check if feature is active
-    my $Access = $ConfigObject->Get('Ticket::Service');
+    my $Access = $Self->{ConfigObject}->Get('Ticket::Service');
 
     if ( !$Access ) {
-        $LayoutObject->FatalError(
-            Message => Translatable('Feature not enabled!'),
-        );
+        $Self->{LayoutObject}->FatalError( Message => 'Feature not enabled!' );
     }
 
-    # get config param
-    my $Config = $ConfigObject->Get("Ticket::Frontend::$Self->{Action}");
-
-    my $SortBy = $ParamObject->GetParam( Param => 'SortBy' )
-        || $Config->{'SortBy::Default'}
+    my $SortBy = $Self->{ParamObject}->GetParam( Param => 'SortBy' )
+        || $Self->{Config}->{'SortBy::Default'}
         || 'Age';
-    my $OrderBy = $ParamObject->GetParam( Param => 'OrderBy' )
-        || $Config->{'Order::Default'}
+    my $OrderBy = $Self->{ParamObject}->GetParam( Param => 'OrderBy' )
+        || $Self->{Config}->{'Order::Default'}
         || 'Up';
 
-    # get session object
-    my $SessionObject = $Kernel::OM->Get('Kernel::System::AuthSession');
-
     # store last queue screen
-    $SessionObject->UpdateSessionID(
+    $Self->{SessionObject}->UpdateSessionID(
         SessionID => $Self->{SessionID},
         Key       => 'LastScreenOverview',
         Value     => $Self->{RequestedURL},
     );
 
     # store last screen
-    $SessionObject->UpdateSessionID(
+    $Self->{SessionObject}->UpdateSessionID(
         SessionID => $Self->{SessionID},
         Key       => 'LastScreenView',
         Value     => $Self->{RequestedURL},
     );
 
-    # get user object
-    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
-
     # get filters stored in the user preferences
-    my %Preferences = $UserObject->GetPreferences(
+    my %Preferences = $Self->{UserObject}->GetPreferences(
         UserID => $Self->{UserID},
     );
     my $StoredFiltersKey = 'UserStoredFilterColumns-' . $Self->{Action};
-    my $JSONObject       = $Kernel::OM->Get('Kernel::System::JSON');
-    my $StoredFilters    = $JSONObject->Decode(
+    my $StoredFilters    = $Self->{JSONObject}->Decode(
         Data => $Preferences{$StoredFiltersKey},
     );
 
     # delete stored filters if needed
-    if ( $ParamObject->GetParam( Param => 'DeleteFilters' ) ) {
+    if ( $Self->{ParamObject}->GetParam( Param => 'DeleteFilters' ) ) {
         $StoredFilters = {};
     }
 
@@ -100,7 +115,7 @@ sub Run {
         )
     {
         # get column filter from web request
-        my $FilterValue = $ParamObject->GetParam( Param => 'ColumnFilter' . $ColumnName )
+        my $FilterValue = $Self->{ParamObject}->GetParam( Param => 'ColumnFilter' . $ColumnName )
             || '';
 
         # if filter is not present in the web request, try with the user preferences
@@ -135,7 +150,7 @@ sub Run {
     }
 
     # get all dynamic fields
-    $Self->{DynamicField} = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldListGet(
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
         Valid      => 1,
         ObjectType => ['Ticket'],
     );
@@ -146,7 +161,7 @@ sub Run {
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
         # get filter from web request
-        my $FilterValue = $ParamObject->GetParam(
+        my $FilterValue = $Self->{ParamObject}->GetParam(
             Param => 'ColumnFilterDynamicField_' . $DynamicFieldConfig->{Name}
         );
 
@@ -165,15 +180,12 @@ sub Run {
         $GetColumnFilter{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = $FilterValue;
     }
 
-    # get service param
-    my $ServiceID = $ParamObject->GetParam( Param => 'ServiceID' ) || 0;
-
     # if we have only one service, check if there
     # is a setting in Config.pm for sorting
     if ( !$OrderBy ) {
-        if ( $Config->{ServiceSort} ) {
-            if ( defined $Config->{ServiceSort}->{$ServiceID} ) {
-                if ( $Config->{ServiceSort}->{$ServiceID} ) {
+        if ( $Self->{Config}->{ServiceSort} ) {
+            if ( defined $Self->{Config}->{ServiceSort}->{ $Self->{ServiceID} } ) {
+                if ( $Self->{Config}->{ServiceSort}->{ $Self->{ServiceID} } ) {
                     $OrderBy = 'Down';
                 }
                 else {
@@ -183,7 +195,7 @@ sub Run {
         }
     }
     if ( !$OrderBy ) {
-        $OrderBy = $Config->{'Order::Default'} || 'Up';
+        $OrderBy = $Self->{Config}->{'Order::Default'} || 'Up';
     }
 
     # build NavigationBar & to get the output faster!
@@ -194,27 +206,24 @@ sub Run {
 
     my $Output;
     if ( $Self->{Subaction} ne 'AJAXFilterUpdate' ) {
-        $Output = $LayoutObject->Header(
+        $Output = $Self->{LayoutObject}->Header(
             Refresh => $Refresh,
         );
-        $Output .= $LayoutObject->NavigationBar();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
     }
 
-    # Notify if there are tickets which are not updated.
-    $Output .= $LayoutObject->NotifyNonUpdatedTickets() // '';
-
     # viewable locks
-    my @ViewableLockIDs = $Kernel::OM->Get('Kernel::System::Lock')->LockViewableLock( Type => 'ID' );
+    my @ViewableLockIDs = $Self->{LockObject}->LockViewableLock( Type => 'ID' );
 
     # viewable states
-    my @ViewableStateIDs = $Kernel::OM->Get('Kernel::System::State')->StateGetStatesByType(
+    my @ViewableStateIDs = $Self->{StateObject}->StateGetStatesByType(
         Type   => 'Viewable',
         Result => 'ID',
     );
 
     # get permissions
     my $Permission = 'rw';
-    if ( $Config->{ViewAllPossibleTickets} ) {
+    if ( $Self->{Config}->{ViewAllPossibleTickets} ) {
         $Permission = 'ro';
     }
 
@@ -222,7 +231,7 @@ sub Run {
     my %Sort;
 
     # get if search result should be pre-sorted by priority
-    my $PreSortByPriority = $Config->{'PreSort::ByPriority'};
+    my $PreSortByPriority = $Self->{Config}->{'PreSort::ByPriority'};
     if ( !$PreSortByPriority ) {
         %Sort = (
             SortBy  => $SortBy,
@@ -237,29 +246,26 @@ sub Run {
     }
 
     # get all queues the agent is allowed to see
-    my %ViewableQueues = $Kernel::OM->Get('Kernel::System::Queue')->GetAllQueues(
+    my %ViewableQueues = $Self->{QueueObject}->GetAllQueues(
         UserID => $Self->{UserID},
         Type   => 'ro',
     );
     my @ViewableQueueIDs = sort keys %ViewableQueues;
 
-    # get service object
-    my $ServiceObject = $Kernel::OM->Get('Kernel::System::Service');
-
     # get custom services
-    my @MyServiceIDs = $ServiceObject->GetAllCustomServices( UserID => $Self->{UserID} );
+    my @MyServiceIDs = $Self->{ServiceObject}->GetAllCustomServices( UserID => $Self->{UserID} );
 
     my @ViewableServiceIDs;
-    if ( !$ServiceID ) {
+    if ( !$Self->{ServiceID} ) {
         @ViewableServiceIDs = @MyServiceIDs;
     }
     else {
-        @ViewableServiceIDs = ($ServiceID);
+        @ViewableServiceIDs = ( $Self->{ServiceID} );
     }
 
     my %Filters = (
         All => {
-            Name   => Translatable('All tickets'),
+            Name   => 'All tickets',
             Prio   => 1000,
             Search => {
                 StateIDs   => \@ViewableStateIDs,
@@ -271,7 +277,7 @@ sub Run {
             },
         },
         Unlocked => {
-            Name   => Translatable('Available tickets'),
+            Name   => 'Available tickets',
             Prio   => 1001,
             Search => {
                 LockIDs    => \@ViewableLockIDs,
@@ -285,48 +291,40 @@ sub Run {
         },
     );
 
-    # get filter param
-    my $Filter = $ParamObject->GetParam( Param => 'Filter' ) || 'Unlocked';
-
     # check if filter is valid
-    if ( !$Filters{$Filter} ) {
-        $LayoutObject->FatalError(
-            Message => $LayoutObject->{LanguageObject}->Translate( 'Invalid Filter: %s!', $Filter ),
-        );
+    if ( !$Filters{ $Self->{Filter} } ) {
+        $Self->{LayoutObject}->FatalError( Message => "Invalid Filter: $Self->{Filter}!" );
     }
 
-    # get view param
-    my $View = $ParamObject->GetParam( Param => 'View' ) || '';
-
     # lookup latest used view mode
-    if ( !$View && $Self->{ 'UserTicketOverview' . $Self->{Action} } ) {
-        $View = $Self->{ 'UserTicketOverview' . $Self->{Action} };
+    if ( !$Self->{View} && $Self->{ 'UserTicketOverview' . $Self->{Action} } ) {
+        $Self->{View} = $Self->{ 'UserTicketOverview' . $Self->{Action} };
     }
 
     # otherwise use Preview as default as in LayoutTicket
-    $View ||= 'Preview';
+    $Self->{View} ||= 'Preview';
 
     # Check if selected view is available.
-    my $Backends = $ConfigObject->Get('Ticket::Frontend::Overview');
-    if ( !$Backends->{$View} ) {
+    my $Backends = $Self->{ConfigObject}->Get('Ticket::Frontend::Overview');
+    if ( !$Backends->{ $Self->{View} } ) {
 
         # Try to find fallback, take first configured view mode.
         KEY:
         for my $Key ( sort keys %{$Backends} ) {
-            $View = $Key;
+            $Self->{View} = $Key;
             last KEY;
         }
     }
 
     # get personal page shown count
-    my $PageShownPreferencesKey = 'UserTicketOverview' . $View . 'PageShown';
-    my $PageShown               = $Self->{$PageShownPreferencesKey} || 10;
+    my $PageShownPreferencesKey = 'UserTicketOverview' . $Self->{View} . 'PageShown';
+    my $PageShown = $Self->{$PageShownPreferencesKey} || 10;
 
     # do shown tickets lookup
     my $Limit = 10_000;
 
-    my $ElementChanged = $ParamObject->GetParam( Param => 'ElementChanged' ) || '';
-    my $HeaderColumn   = $ElementChanged;
+    my $ElementChanged = $Self->{ParamObject}->GetParam( Param => 'ElementChanged' ) || '';
+    my $HeaderColumn = $ElementChanged;
     $HeaderColumn =~ s{\A ColumnFilter }{}msxg;
 
     # get data (viewable tickets...)
@@ -334,9 +332,6 @@ sub Run {
     my @ViewableTickets;
     my @OriginalViewableTickets;
 
-    # get ticket object
-    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
-
     if ( @ViewableQueueIDs && @ViewableServiceIDs ) {
 
         # get ticket values
@@ -345,26 +340,23 @@ sub Run {
             || (
                 IsStringWithData($HeaderColumn)
                 && (
-                    $ConfigObject->Get('OnlyValuesOnTicket') ||
+                    $Self->{ConfigObject}->Get('OnlyValuesOnTicket') ||
                     $HeaderColumn eq 'CustomerID' ||
                     $HeaderColumn eq 'CustomerUserID'
                 )
             )
             )
         {
-            @OriginalViewableTickets = $TicketObject->TicketSearch(
-                %{ $Filters{$Filter}->{Search} },
+            @OriginalViewableTickets = $Self->{TicketObject}->TicketSearch(
+                %{ $Filters{ $Self->{Filter} }->{Search} },
                 Limit  => $Limit,
                 Result => 'ARRAY',
             );
 
-            # get start param
-            my $Start = $ParamObject->GetParam( Param => 'StartHit' ) || 1;
-
-            @ViewableTickets = $TicketObject->TicketSearch(
-                %{ $Filters{$Filter}->{Search} },
+            @ViewableTickets = $Self->{TicketObject}->TicketSearch(
+                %{ $Filters{ $Self->{Filter} }->{Search} },
                 %ColumnFilter,
-                Limit  => $Start + $PageShown - 1,
+                Limit  => $Self->{Start} + $PageShown - 1,
                 Result => 'ARRAY',
             );
         }
@@ -373,26 +365,25 @@ sub Run {
 
     if ( $Self->{Subaction} eq 'AJAXFilterUpdate' ) {
 
-        my $FilterContent = $LayoutObject->TicketListShow(
+        my $FilterContent = $Self->{LayoutObject}->TicketListShow(
             FilterContentOnly   => 1,
             HeaderColumn        => $HeaderColumn,
             ElementChanged      => $ElementChanged,
             OriginalTicketIDs   => \@OriginalViewableTickets,
             Action              => 'AgentTicketService',
             Env                 => $Self,
-            View                => $View,
+            View                => $Self->{View},
             EnableColumnFilters => 1,
         );
 
         if ( !$FilterContent ) {
-            $LayoutObject->FatalError(
-                Message => $LayoutObject->{LanguageObject}
-                    ->Translate( 'Can\'t get filter content data of %s!', $HeaderColumn ),
+            $Self->{LayoutObject}->FatalError(
+                Message => "Can't get filter content data of $HeaderColumn!",
             );
         }
 
-        return $LayoutObject->Attachment(
-            ContentType => 'application/json; charset=' . $LayoutObject->{Charset},
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'application/json; charset=' . $Self->{LayoutObject}->{Charset},
             Content     => $FilterContent,
             Type        => 'inline',
             NoCache     => 1,
@@ -404,33 +395,33 @@ sub Run {
         my $StoredFilters = \%ColumnFilter;
 
         my $StoredFiltersKey = 'UserStoredFilterColumns-' . $Self->{Action};
-        $UserObject->SetPreferences(
+        $Self->{UserObject}->SetPreferences(
             UserID => $Self->{UserID},
             Key    => $StoredFiltersKey,
-            Value  => $JSONObject->Encode( Data => $StoredFilters ),
+            Value  => $Self->{JSONObject}->Encode( Data => $StoredFilters ),
         );
     }
 
     my $CountTotal = 0;
     my %NavBarFilter;
-    for my $FilterColumn ( sort keys %Filters ) {
+    for my $Filter ( sort keys %Filters ) {
         my $Count = 0;
         if ( @ViewableQueueIDs && @ViewableServiceIDs ) {
-            $Count = $TicketObject->TicketSearch(
-                %{ $Filters{$FilterColumn}->{Search} },
+            $Count = $Self->{TicketObject}->TicketSearch(
+                %{ $Filters{$Filter}->{Search} },
                 %ColumnFilter,
                 Result => 'COUNT',
-            ) || 0;
+            );
         }
 
-        if ( $FilterColumn eq $Filter ) {
+        if ( $Filter eq $Self->{Filter} ) {
             $CountTotal = $Count;
         }
 
-        $NavBarFilter{ $Filters{$FilterColumn}->{Prio} } = {
+        $NavBarFilter{ $Filters{$Filter}->{Prio} } = {
             Count  => $Count,
-            Filter => $FilterColumn,
-            %{ $Filters{$FilterColumn} },
+            Filter => $Filter,
+            %{ $Filters{$Filter} },
         };
     }
 
@@ -441,37 +432,37 @@ sub Run {
         next COLUMNNAME if !defined $GetColumnFilter{$ColumnName};
         next COLUMNNAME if $GetColumnFilter{$ColumnName} eq '';
         $ColumnFilterLink
-            .= ';' . $LayoutObject->Ascii2Html( Text => 'ColumnFilter' . $ColumnName )
-            . '=' . $LayoutObject->LinkEncode( $GetColumnFilter{$ColumnName} );
+            .= ';' . $Self->{LayoutObject}->Ascii2Html( Text => 'ColumnFilter' . $ColumnName )
+            . '=' . $Self->{LayoutObject}->Ascii2Html( Text => $GetColumnFilter{$ColumnName} )
     }
 
     my $LinkPage = 'ServiceID='
-        . $LayoutObject->Ascii2Html( Text => $ServiceID )
+        . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{ServiceID} )
         . ';Filter='
-        . $LayoutObject->Ascii2Html( Text => $Filter )
-        . ';View=' . $LayoutObject->Ascii2Html( Text => $View )
-        . ';SortBy=' . $LayoutObject->Ascii2Html( Text => $SortBy )
-        . ';OrderBy=' . $LayoutObject->Ascii2Html( Text => $OrderBy )
+        . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{Filter} )
+        . ';View=' . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{View} )
+        . ';SortBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $SortBy )
+        . ';OrderBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $OrderBy )
         . $ColumnFilterLink
         . ';';
     my $LinkSort = 'ServiceID='
-        . $LayoutObject->Ascii2Html( Text => $ServiceID )
-        . ';View=' . $LayoutObject->Ascii2Html( Text => $View )
+        . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{ServiceID} )
+        . ';View=' . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{View} )
         . ';Filter='
-        . $LayoutObject->Ascii2Html( Text => $Filter )
+        . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{Filter} )
         . $ColumnFilterLink
         . ';';
 
     my $LinkFilter = 'ServiceID='
-        . $LayoutObject->Ascii2Html( Text => $ServiceID )
-        . ';SortBy=' . $LayoutObject->Ascii2Html( Text => $SortBy )
-        . ';OrderBy=' . $LayoutObject->Ascii2Html( Text => $OrderBy )
-        . ';View=' . $LayoutObject->Ascii2Html( Text => $View )
+        . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{ServiceID} )
+        . ';SortBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $SortBy )
+        . ';OrderBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $OrderBy )
+        . ';View=' . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{View} )
         . ';';
 
     # get all services
-    my %AllServices = $ServiceObject->ServiceList(
-        Valid  => 0,
+    my %AllServices = $Self->{ServiceObject}->ServiceList(
+        Valid  => 1,
         UserID => $Self->{UserID},
     );
 
@@ -483,7 +474,7 @@ sub Run {
     # get the agent custom services count
     if (@MyServiceIDs) {
 
-        $Count = $TicketObject->TicketSearch(
+        $Count = $Self->{TicketObject}->TicketSearch(
             LockIDs    => \@ViewableLockIDs,
             StateIDs   => \@ViewableStateIDs,
             QueueIDs   => \@ViewableQueueIDs,
@@ -491,7 +482,7 @@ sub Run {
             Permission => $Permission,
             UserID     => $Self->{UserID},
             Result     => 'COUNT',
-        ) || 0;
+        );
     }
 
     # add the count for the custom services
@@ -504,44 +495,34 @@ sub Run {
     # remember the number shown tickets for the custom services
     $Data{TicketsShown} = $Count || 0;
 
-    # Get ticket count for all services.
-    my @ServiceIDs           = sort { $AllServices{$a} cmp $AllServices{$b} } keys %AllServices;
-    my @AllServicesTicketIDs = $TicketObject->TicketSearch(
-        LockIDs    => \@ViewableLockIDs,
-        StateIDs   => \@ViewableStateIDs,
-        QueueIDs   => \@ViewableQueueIDs,
-        ServiceIDs => \@ServiceIDs,
-        Permission => $Permission,
-        UserID     => $Self->{UserID},
-        Limit      => 20_000,
-        Result     => 'ARRAY',
-    );
-
-    my $TicketCountByServiceID = $TicketObject->TicketCountByAttribute(
-        Attribute => 'ServiceID',
-        TicketIDs => \@AllServicesTicketIDs,
-    );
-
     SERVICEID:
-    for my $ServiceIDItem (@ServiceIDs) {
-        my $ServiceIDCount = $TicketCountByServiceID->{$ServiceIDItem};
+    for my $ServiceID ( sort { $AllServices{$a} cmp $AllServices{$b} } keys %AllServices ) {
 
-        next SERVICEID if !$ServiceIDCount;
+        $Count = $Self->{TicketObject}->TicketSearch(
+            LockIDs    => \@ViewableLockIDs,
+            StateIDs   => \@ViewableStateIDs,
+            QueueIDs   => \@ViewableQueueIDs,
+            ServiceIDs => [$ServiceID],
+            Permission => $Permission,
+            UserID     => $Self->{UserID},
+            Result     => 'COUNT',
+        );
+
+        next SERVICEID if !$Count;
 
         push @{ $Data{Services} }, {
-            Count     => $ServiceIDCount,
-            Service   => $AllServices{$ServiceIDItem},
-            ServiceID => $ServiceIDItem,
+            Count     => $Count,
+            Service   => $AllServices{$ServiceID},
+            ServiceID => $ServiceID,
         };
 
-        # Remember the number of shown tickets for the selected service.
-        next SERVICEID if !$ServiceID;
-        next SERVICEID if $ServiceID ne $ServiceIDItem;
-
-        $Data{TicketsShown} = $ServiceIDCount;
+        # remember the number shown tickets for the selected service
+        if ( $Self->{ServiceID} && $Self->{ServiceID} eq $ServiceID ) {
+            $Data{TicketsShown} = $Count || 0;
+        }
     }
 
-    my $LastColumnFilter = $ParamObject->GetParam( Param => 'LastColumnFilter' ) || '';
+    my $LastColumnFilter = $Self->{ParamObject}->GetParam( Param => 'LastColumnFilter' ) || '';
 
     if ( !$LastColumnFilter && $ColumnFilterLink ) {
 
@@ -551,16 +532,17 @@ sub Run {
 
     my %NavBar = $Self->_MaskServiceView(
         %Data,
-        ServiceID   => $ServiceID,
+        ServiceID   => $Self->{ServiceID},
         AllServices => \%AllServices,
     );
 
     # show tickets
-    $Output .= $LayoutObject->TicketListShow(
-        Filter  => $Filter,
-        Filters => \%NavBarFilter,
+    $Output .= $Self->{LayoutObject}->TicketListShow(
+        Filter     => $Self->{Filter},
+        Filters    => \%NavBarFilter,
+        FilterLink => $LinkFilter,
 
-        DataInTheMiddle => $LayoutObject->Output(
+        DataInTheMiddle => $Self->{LayoutObject}->Output(
             TemplateFile => 'AgentTicketService',
             Data         => \%NavBar,
         ),
@@ -575,10 +557,10 @@ sub Run {
         RequestedURL      => $Self->{RequestedURL},
 
         NavBar => \%NavBar,
-        View   => $View,
+        View   => $Self->{View},
 
         Bulk       => 1,
-        TitleName  => Translatable('Service View'),
+        TitleName  => 'Service View',
         TitleValue => $NavBar{SelectedService},
 
         Env        => $Self,
@@ -590,8 +572,8 @@ sub Run {
         SortBy              => $SortBy,
         EnableColumnFilters => 1,
         ColumnFilterForm    => {
-            ServiceID => $ServiceID || '',
-            Filter    => $Filter    || '',
+            ServiceID => $Self->{ServiceID} || '',
+            Filter    => $Self->{Filter}    || '',
         },
 
         # do not print the result earlier, but return complete content
@@ -599,32 +581,25 @@ sub Run {
     );
 
     # get page footer
-    $Output .= $LayoutObject->Footer() if $Self->{Subaction} ne 'AJAXFilterUpdate';
+    $Output .= $Self->{LayoutObject}->Footer() if $Self->{Subaction} ne 'AJAXFilterUpdate';
     return $Output;
 }
 
 sub _MaskServiceView {
     my ( $Self, %Param ) = @_;
 
-    # get needed objects
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
-    my $CustomService
-        = $LayoutObject->{LanguageObject}->Translate( $ConfigObject->Get('Ticket::CustomService') || 'My Services' );
-    my $Config = $ConfigObject->Get("Ticket::Frontend::$Self->{Action}");
-
-    my $ServiceID   = $Param{ServiceID} || 0;
+    my $ServiceID = $Param{ServiceID} || 0;
     my @ServicesNew = @{ $Param{Services} };
+
     my %AllServices = %{ $Param{AllServices} };
     my %Counter;
     my %UsedService;
     my @ListedServices;
-    my $Level = 0;
-
-    $Self->{HighlightAge1} = $Config->{HighlightAge1};
-    $Self->{HighlightAge2} = $Config->{HighlightAge2};
-    $Self->{Blink}         = $Config->{Blink};
+    my $Level         = 0;
+    my $CustomService = $Self->{LayoutObject}->{LanguageObject}->Translate( $Self->{CustomService} );
+    $Self->{HighlightAge1} = $Self->{Config}->{HighlightAge1};
+    $Self->{HighlightAge2} = $Self->{Config}->{HighlightAge2};
+    $Self->{Blink}         = $Self->{Config}->{Blink};
 
     $Param{SelectedService} = $AllServices{$ServiceID} || $CustomService;
     my @MetaService = split /::/, $Param{SelectedService};
@@ -680,16 +655,13 @@ sub _MaskServiceView {
             $Counter{$CustomService} = $Counter{ $Service{Service} };
             $Service{Service} = $CustomService;
         }
-        my @ServiceName      = split /::/, $Service{Service};
+        my @ServiceName = split /::/, $Service{Service};
         my $ShortServiceName = $ServiceName[-1];
         $Service{ServiceID} = 0 if ( !$Service{ServiceID} );
 
-        # get view param
-        my $View = $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => 'View' ) || '';
-
         $ServiceStrg
-            .= "<li><a href=\"$LayoutObject->{Baselink}Action=AgentTicketService;ServiceID=$Service{ServiceID}";
-        $ServiceStrg .= ';View=' . $LayoutObject->Ascii2Html( Text => $View ) . '"';
+            .= "<li><a href=\"$Self->{LayoutObject}->{Baselink}Action=AgentTicketService;ServiceID=$Service{ServiceID}";
+        $ServiceStrg .= ';View=' . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{View} ) . '"';
 
         $ServiceStrg .= ' class="';
 
@@ -739,7 +711,7 @@ sub _MaskServiceView {
         }
 
         # ServiceStrg
-        $ServiceStrg .= $LayoutObject->Ascii2Html( Text => $ShortServiceName )
+        $ServiceStrg .= $Self->{LayoutObject}->Ascii2Html( Text => $ShortServiceName )
             . " ($Counter{$Service{Service}})";
 
         $ServiceStrg .= '</a></li>';
