@@ -1,19 +1,19 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::Template::Provider;
 ## no critic(Perl::Critic::Policy::OTRS::RequireCamelCase)
-## nofilter(TidyAll::Plugin::OTRS::Perl::SyntaxCheck)
+## nofilter(TidyAll::Plugin::OTRS::Perl::SyntaxCheck) # bails on TT Constants
 
 use strict;
 use warnings;
 
-use parent qw (Template::Provider);
+use base qw (Template::Provider);
 
 use Scalar::Util qw();
 use Template::Constants;
@@ -37,9 +37,13 @@ Kernel::Output::Template::Provider - Template Toolkit custom provider
 
 =head1 PUBLIC INTERFACE
 
-=head2 OTRSInit()
+=over 4
 
-performs some post-initialization and creates a bridge between Template::Toolkit
+=cut
+
+=item OTRSInit()
+
+performs some post-initialization and creates a bridget between Template::Toolkit
 and OTRS by adding the OTRS objects to the Provider object. This method must be
 called after instantiating the Provider object.
 
@@ -68,12 +72,64 @@ sub OTRSInit {
     # caching can be disabled for debugging reasons
     $Self->{CachingEnabled} = $Kernel::OM->Get('Kernel::Config')->Get('Frontend::TemplateCache') // 1;
 
-    return;
+    #
+    # Pre-compute the list of not cacheable Templates. If a pre-output filter is
+    #   registered for a particular or for all templates, the template cannot be
+    #   cached any more.
+    #
+    $Self->{FilterElementPre} = $Kernel::OM->Get('Kernel::Config')->Get('Frontend::Output::FilterElementPre');
+
+    my %UncacheableTemplates;
+
+    my %FilterList = %{ $Self->{FilterElementPre} || {} };
+
+    FILTER:
+    for my $Filter ( sort keys %FilterList ) {
+
+        # extract filter config
+        my $FilterConfig = $FilterList{$Filter};
+
+        next FILTER if !$FilterConfig;
+        next FILTER if ref $FilterConfig ne 'HASH';
+
+        # extract template list
+        my %TemplateList = %{ $FilterConfig->{Templates} || {} };
+
+        if ( !%TemplateList ) {
+
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message =>
+                    "Please add a template list to output filter $FilterConfig->{Module} to improve performance.",
+            );
+
+            next FILTER;
+        }
+        elsif ( $TemplateList{ALL} ) {
+
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => <<EOF,
+$FilterConfig->{Module} wants to operate on ALL templates.
+This will prohibit the templates from being cached and can therefore lead to serious performance issues.
+EOF
+            );
+
+            next FILTER;
+        }
+
+        @UncacheableTemplates{ keys %TemplateList } = values %TemplateList;
+    }
+
+    # map filtered template names to real tt names (except 'ALL' placeholder)
+    %UncacheableTemplates =
+        map { $_ eq 'ALL' ? 'ALL' : $_ . '.tt' => $UncacheableTemplates{$_} }
+        keys %UncacheableTemplates;
+
+    $Self->{UncacheableTemplates} = \%UncacheableTemplates;
 }
 
-=begin Internal:
-
-=head2 _fetch()
+=item _fetch()
 
 try to get a compiled version of a template from the CacheObject,
 otherwise compile the template and return it.
@@ -82,9 +138,9 @@ Copied and slightly adapted from Template::Provider.
 
 A note about caching: we have three levels of caching.
 
-    1. we have an in-memory cache that stores the compiled Document objects (fastest).
-    2. we store the parsed data in the CacheObject to be re-used in another request.
-    3. for string templates, we have an in-memory cache in the parsing method _compile().
+    1. For cacheable templates, we have an in-memory cache that stores the compiled Document objects (fastest).
+    2. For cacheable templates, we store the parsed data in the CacheObject to be re-used in another request.
+    3. For non-cacheable templates and string templates, we have an in-memory cache in the parsing method _compile().
         It will return the already parsed object if it sees the same template content again.
 
 =cut
@@ -95,10 +151,12 @@ sub _fetch {
 
     $self->debug("_fetch($name)") if $self->{DEBUG};
 
+    my $TemplateIsCacheable = !$self->{UncacheableTemplates}->{ALL} && !$self->{UncacheableTemplates}->{$t_name};
+
     # Check in-memory template cache if we already had this template.
     $self->{_TemplateCache} //= {};
 
-    if ( $self->{_TemplateCache}->{$name} ) {
+    if ( $TemplateIsCacheable && $self->{_TemplateCache}->{$name} ) {
         return $self->{_TemplateCache}->{$name};
     }
 
@@ -108,11 +166,10 @@ sub _fetch {
     }
 
     # Check if the template exists, is cacheable and if a cached version exists.
-    if ( -e $name && $self->{CachingEnabled} ) {
+    if ( -e $name && $TemplateIsCacheable && $self->{CachingEnabled} ) {
 
-        my $UserTheme      = $self->{LayoutObject}->{EnvRef}->{UserTheme};
         my $template_mtime = $self->_template_modified($name);
-        my $CacheKey       = $self->_compiled_filename($name) . '::' . $template_mtime . '::' . $UserTheme;
+        my $CacheKey       = $self->_compiled_filename($name) . '::' . $template_mtime;
 
         # Is there an up-to-date compiled version in the cache?
         my $Cache = $Kernel::OM->Get('Kernel::System::Cache')->Get(
@@ -161,18 +218,22 @@ sub _fetch {
         return ( $template, $error );
     }
 
-    # Make sure template cache does not get too big
-    if ( keys %{ $self->{_TemplateCache} } > 1000 ) {
-        $self->{_TemplateCache} = {};
+    if ($TemplateIsCacheable) {
+
+        # Make sure template cache does not get too big
+        if ( keys %{ $self->{_TemplateCache} } > 1000 ) {
+            $self->{_TemplateCache} = {};
+        }
+
+        $self->{_TemplateCache}->{$name} = $template->{data};
     }
 
-    $self->{_TemplateCache}->{$name} = $template->{data};
-
+    # If we cannot cache the template, just return it.
     return $template->{data};
 
 }
 
-=head2 _load()
+=item _load()
 
 calls our pre processor when loading a template.
 
@@ -197,7 +258,7 @@ sub _load {
     return @Result;
 }
 
-=head2 _compile()
+=item _compile()
 
 compiles a .tt template into a Perl package and uses the CacheObject
 to cache it.
@@ -243,16 +304,21 @@ sub _compile {
 
         # write the Perl code to the file $compfile, if defined
         if ($compfile) {
-            my $UserTheme = $self->{LayoutObject}->{EnvRef}->{UserTheme};
-            my $CacheKey  = $compfile . '::' . $data->{time} . '::' . $UserTheme;
 
-            if ( $self->{CachingEnabled} ) {
-                $Kernel::OM->Get('Kernel::System::Cache')->Set(
-                    Type  => $self->{CacheType},
-                    TTL   => 60 * 60 * 24,
-                    Key   => $CacheKey,
-                    Value => $parsedoc,
-                );
+            my $TemplateIsCacheable = !$self->{UncacheableTemplates}->{ALL}
+                && !$self->{UncacheableTemplates}->{ $data->{name} };
+
+            if ($TemplateIsCacheable) {
+                my $CacheKey = $compfile . '::' . $data->{time};
+
+                if ( $self->{CachingEnabled} ) {
+                    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+                        Type  => $self->{CacheType},
+                        TTL   => 60 * 60 * 24,
+                        Key   => $CacheKey,
+                        Value => $parsedoc,
+                    );
+                }
             }
         }
 
@@ -276,12 +342,10 @@ sub _compile {
     # return STATUS_ERROR, or STATUS_DECLINED if we're being tolerant
     return $self->{TOLERANT}
         ? ( undef, Template::Constants::STATUS_DECLINED )
-        : ( $error, Template::Constants::STATUS_ERROR );
+        : ( $error, Template::Constants::STATUS_ERROR )
 }
 
-=end Internal:
-
-=head2 store()
+=item store()
 
 inherited from Template::Provider. This function override just makes sure that the original
 in-memory cache cannot be used.
@@ -294,13 +358,11 @@ sub store {
     return $Data;    # no-op
 }
 
-=begin Internal:
-
-=head2 _PreProcessTemplateContent()
+=item _PreProcessTemplateContent()
 
 this is our template pre processor.
 
-It handles some OTRS specific tags like [% InsertTemplate("TemplateName.tt") %]
+It handles pre output filters, some OTRS specific tags like [% InsertTemplate("TemplateName.tt") %]
 and also performs compile-time code injection (ChallengeToken element into forms).
 
 Besides that, it also makes sure the template is treated as UTF8.
@@ -342,10 +404,78 @@ sub _PreProcessTemplateContent {
 
     } until ( !$Replaced || ++$ReplaceCounter > 100 );
 
+    #
+    # pre putput filter handling
+    #
+    if ( $Self->{FilterElementPre} && ref $Self->{FilterElementPre} eq 'HASH' ) {
+
+        # extract filter list
+        my %FilterList = %{ $Self->{FilterElementPre} };
+
+        FILTER:
+        for my $Filter ( sort keys %FilterList ) {
+
+            # extract filter config
+            my $FilterConfig = $FilterList{$Filter};
+
+            next FILTER if !$FilterConfig;
+            next FILTER if ref $FilterConfig ne 'HASH';
+
+            # extract template list
+            my %TemplateList = %{ $FilterConfig->{Templates} || {} };
+
+            if ( !%TemplateList ) {
+
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                    Priority => 'error',
+                    Message =>
+                        "Please add a template list to output filter $FilterConfig->{Module} to improve performance.",
+                );
+
+                next FILTER;
+            }
+            elsif ( $TemplateList{ALL} ) {
+
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                    Priority => 'error',
+                    Message  => <<EOF,
+$FilterConfig->{Module} wants to operate on ALL templates.
+This will prohibit the templates from being cached and can therefore lead to serious performance issues.
+EOF
+                );
+
+                next FILTER;
+            }
+
+            # only operate on real files
+            next FILTER if !$Param{TemplateFile};
+
+            # check template list
+            next FILTER if !$TemplateList{$TemplateFileWithoutTT};
+
+            # check filter construction
+            next FILTER if !$Kernel::OM->Get('Kernel::System::Main')->Require( $FilterConfig->{Module} );
+
+            # create new instance
+            my $Object = $FilterConfig->{Module}->new(
+                LayoutObject => $Self->{LayoutObject},
+            );
+
+            next FILTER if !$Object;
+
+            # run output filter
+            $Object->Run(
+                %{$FilterConfig},
+                Data         => \$Content,
+                TemplateFile => $TemplateFileWithoutTT || '',
+            );
+        }
+    }
+
     #
     # Remove DTL-style comments (lines starting with #)
     #
-    $Content =~ s/^#.*\n//gm if !$ENV{TEMPLATE_KEEP_COMMENTS};
+    $Content =~ s/^#.*\n//gm;
 
     #
     # Insert a BLOCK call into the template.
@@ -380,15 +510,13 @@ sub _PreProcessTemplateContent {
 
 }
 
-=end Internal:
+=item MigrateDTLtoTT()
 
-=head2 MigrateDTLtoTT()
-
-translates old C<DTL> template content to L<Template::Toolkit> syntax.
+translates old DTL template content to Template::Toolkit syntax.
 
     my $TTCode = $ProviderObject->MigrateDTLtoTT( Content => $DTLCode );
 
-If an error was found, this method will C<die()>, so please use eval around it.
+If an error was found, this method will die(), so please use eval around it.
 
 =cut
 
@@ -408,14 +536,14 @@ sub MigrateDTLtoTT {
     };
 
     # $Quote $Config
-    $Content =~ s{\$Quote[{]"\$Config[{]"($ID)"}"}}{[% Config("$1") | html %]}smxg;
+    $Content =~ s{\$Quote{"\$Config{"($ID)"}"}}{[% Config("$1") | html %]}smxg;
 
     # $Quote $Env
-    $Content =~ s{\$Quote[{]"\$Env[{]"($ID)"}"}}{[% Env("$1") | html %]}smxg;
+    $Content =~ s{\$Quote{"\$Env{"($ID)"}"}}{[% Env("$1") | html %]}smxg;
 
     # $Quote $Data
     $Content =~ s{
-            \$Quote[{]"\$Data[{]"($ID)"}"}
+            \$Quote{"\$Data{"($ID)"}"}
         }
         {
             '[% Data.' . $SafeArrrayAccess->($1) . ' | html %]'
@@ -423,7 +551,7 @@ sub MigrateDTLtoTT {
 
     # $Quote with length
     $Content =~ s{
-            \$Quote[{]"\$Data[{]"($ID)"}",\s*"(\d+)"}
+            \$Quote{"\$Data{"($ID)"}",\s*"(\d+)"}
         }
         {
             '[% Data.' . $SafeArrrayAccess->($1) . " | truncate($2) | html %]"
@@ -431,7 +559,7 @@ sub MigrateDTLtoTT {
 
     # $Quote with dynamic length
     $Content =~ s{
-            \$Quote[{]"\$Data[{]"($ID)"}",\s*"\$Q?Data[{]"($ID)"}"}
+            \$Quote{"\$Data{"($ID)"}",\s*"\$Q?Data{"($ID)"}"}
         }
         {
             '[% Data.' . $SafeArrrayAccess->($1) . ' | truncate(Data.' . $SafeArrrayAccess->($2) . ') | html %]'
@@ -439,7 +567,7 @@ sub MigrateDTLtoTT {
 
     # $Quote with translated text and fixed length
     $Content =~ s{
-            \$Quote[{]"\$Text[{]"\$Data[{]"($ID)"}"}",\s*"(\d+)"}
+            \$Quote{"\$Text{"\$Data{"($ID)"}"}",\s*"(\d+)"}
         }
         {
             '[% Data.' . $SafeArrrayAccess->($1) . " | Translate | truncate($2) | html %]"
@@ -447,7 +575,7 @@ sub MigrateDTLtoTT {
 
     # $Quote with translated text and dynamic length
     $Content =~ s{
-            \$Quote[{]"\$Text[{]"\$Data[{]"($ID)"}"}",\s*"\$Q?Data[{]"($ID)"}"}
+            \$Quote{"\$Text{"\$Data{"($ID)"}"}",\s*"\$Q?Data{"($ID)"}"}
         }
         {
             '[% Data.' . $SafeArrrayAccess->($1) . ' | Translate | truncate(Data.' . $SafeArrrayAccess->($2) . ') | html %]'
@@ -463,22 +591,22 @@ sub MigrateDTLtoTT {
         my $Result = '[% ';
 
         # Text contains a tag
-        if ( $Text =~ m{\$TimeLong[{]"\$Q?Data[{]"($ID)"}"}}smx ) {
+        if ( $Text =~ m{\$TimeLong{"\$Q?Data{"($ID)"}"}}smx ) {
             $Result .= "Translate(Localize(Data." . $SafeArrrayAccess->($1) . ", \"TimeLong\")";
         }
-        elsif ( $Text =~ m{\$TimeShort[{]"\$Q?Data[{]"($ID)"}"}}smx ) {
+        elsif ( $Text =~ m{\$TimeShort{"\$Q?Data{"($ID)"}"}}smx ) {
             $Result .= "Translate(Localize(Data." . $SafeArrrayAccess->($1) . ", \"TimeShort\")";
         }
-        elsif ( $Text =~ m{\$Date[{]"\$Q?Data[{]"($ID)"}"}}smx ) {
+        elsif ( $Text =~ m{\$Date{"\$Q?Data{"($ID)"}"}}smx ) {
             $Result .= "Translate(Localize(Data." . $SafeArrrayAccess->($1) . ", \"Date\")";
         }
-        elsif ( $Text =~ m{\$Q?Data[{]"($ID)"}}smx ) {
+        elsif ( $Text =~ m{\$Q?Data{"($ID)"}}smx ) {
             $Result .= "Translate(Data." . $SafeArrrayAccess->($1) . "";
         }
-        elsif ( $Text =~ m{\$Config[{]"($ID)"}}smx ) {
+        elsif ( $Text =~ m{\$Config{"($ID)"}}smx ) {
             $Result .= "Translate(Config(\"$1\")";
         }
-        elsif ( $Text =~ m{\$Q?Env[{]"($ID)"}}smx ) {
+        elsif ( $Text =~ m{\$Q?Env{"($ID)"}}smx ) {
             $Result .= "Translate(Env(\"$1\")";
         }
 
@@ -496,22 +624,22 @@ sub MigrateDTLtoTT {
         PARAMETER:
         for my $Parameter (@Parameters) {
             next PARAMETER if ( !$Parameter );
-            if ( $Parameter =~ m{\$TimeLong[{]"\$Q?Data[{]"($ID)"}"}}smx ) {
+            if ( $Parameter =~ m{\$TimeLong{"\$Q?Data{"($ID)"}"}}smx ) {
                 $Result .= ", Localize(Data.$1, \"TimeLong\")";
             }
-            elsif ( $Parameter =~ m{\$TimeShort[{]"\$Q?Data[{]"($ID)"}"}}smx ) {
+            elsif ( $Parameter =~ m{\$TimeShort{"\$Q?Data{"($ID)"}"}}smx ) {
                 $Result .= ", Localize(Data.$1, \"TimeShort\")";
             }
-            elsif ( $Parameter =~ m{\$Date[{]"\$Q?Data[{]"($ID)"}"}}smx ) {
+            elsif ( $Parameter =~ m{\$Date{"\$Q?Data{"($ID)"}"}}smx ) {
                 $Result .= ", Localize(Data.$1, \"Date\")";
             }
-            elsif ( $Parameter =~ m{\$Q?Data[{]"($ID)"}}smx ) {
+            elsif ( $Parameter =~ m{\$Q?Data{"($ID)"}}smx ) {
                 $Result .= ", Data.$1";
             }
-            elsif ( $Parameter =~ m{\$Config[{]"($ID)"}}smx ) {
+            elsif ( $Parameter =~ m{\$Config{"($ID)"}}smx ) {
                 $Result .= ", Config(\"$1\")";
             }
-            elsif ( $Parameter =~ m{\$Q?Env[{]"($ID)"}}smx ) {
+            elsif ( $Parameter =~ m{\$Q?Env{"($ID)"}}smx ) {
                 $Result .= ", Env(\"$1\")";
             }
             else {
@@ -535,28 +663,28 @@ sub MigrateDTLtoTT {
 
     # $Text
     $Content =~ s{
-            \$Text[{]
+            \$Text{
                 ["']
                 (
                     [^\$]+?
-                    |\$Q?Data[{]\"$ID\"}
-                    |\$Config[{]\"$ID\"}
-                    |\$Q?Env[{]\"$ID\"}
-                    |\$TimeLong[{]\"\$Q?Data[{]\"$ID\"}\"}
-                    |\$TimeShort[{]\"\$Q?Data[{]\"$ID\"}\"}
-                    |\$Date[{]\"\$Q?Data[{]\"$ID\"}\"}
+                    |\$Q?Data{\"$ID\"}
+                    |\$Config{\"$ID\"}
+                    |\$Q?Env{\"$ID\"}
+                    |\$TimeLong{\"\$Q?Data{\"$ID\"}\"}
+                    |\$TimeShort{\"\$Q?Data{\"$ID\"}\"}
+                    |\$Date{\"\$Q?Data{\"$ID\"}\"}
                 )
                 ["']
                 ((?:
                     ,\s*["']
                     (?:
                         [^\$]+?
-                        |\$Q?Data[{]\"$ID\"}
-                        |\$Config[{]\"$ID\"}
-                        |\$Q?Env[{]\"$ID\"}
-                        |\$TimeLong[{]\"\$Q?Data[{]\"$ID\"}\"}
-                        |\$TimeShort[{]\"\$Q?Data[{]\"$ID\"}\"}
-                        |\$Date[{]\"\$Q?Data[{]\"$ID\"}\"}
+                        |\$Q?Data{\"$ID\"}
+                        |\$Config{\"$ID\"}
+                        |\$Q?Env{\"$ID\"}
+                        |\$TimeLong{\"\$Q?Data{\"$ID\"}\"}
+                        |\$TimeShort{\"\$Q?Data{\"$ID\"}\"}
+                        |\$Date{\"\$Q?Data{\"$ID\"}\"}
                     )
                 ["'])*)
             }
@@ -570,28 +698,28 @@ sub MigrateDTLtoTT {
 
     # $JSText
     $Content =~ s{
-            ["']\$JSText[{]
+            ["']\$JSText{
                 ["']
                 (
                     [^\$]+?
-                    |\$Q?Data[{]\"$ID\"}
-                    |\$Config[{]\"$ID\"}
-                    |\$Q?Env[{]\"$ID\"}
-                    |\$TimeLong[{]\"\$Q?Data[{]\"$ID\"}\"}
-                    |\$TimeShort[{]\"\$Q?Data[{]\"$ID\"}\"}
-                    |\$Date[{]\"\$Q?Data[{]\"$ID\"}\"}
+                    |\$Q?Data{\"$ID\"}
+                    |\$Config{\"$ID\"}
+                    |\$Q?Env{\"$ID\"}
+                    |\$TimeLong{\"\$Q?Data{\"$ID\"}\"}
+                    |\$TimeShort{\"\$Q?Data{\"$ID\"}\"}
+                    |\$Date{\"\$Q?Data{\"$ID\"}\"}
                 )
                 ["']
                 ((?:
                     ,\s*["']
                     (?:
                         [^\$]+?
-                        |\$Q?Data[{]\"$ID\"}
-                        |\$Config[{]\"$ID\"}
-                        |\$Q?Env[{]\"$ID\"}
-                        |\$TimeLong[{]\"\$Q?Data[{]\"$ID\"}\"}
-                        |\$TimeShort[{]\"\$Q?Data[{]\"$ID\"}\"}
-                        |\$Date[{]\"\$Q?Data[{]\"$ID\"}\"}
+                        |\$Q?Data{\"$ID\"}
+                        |\$Config{\"$ID\"}
+                        |\$Q?Env{\"$ID\"}
+                        |\$TimeLong{\"\$Q?Data{\"$ID\"}\"}
+                        |\$TimeShort{\"\$Q?Data{\"$ID\"}\"}
+                        |\$Date{\"\$Q?Data{\"$ID\"}\"}
                     )
                 ["'])*)
             }
@@ -602,17 +730,17 @@ sub MigrateDTLtoTT {
         }esmxg;
 
     # $TimeLong
-    $Content =~ s{\$TimeLong[{]"\$Q?Data[{]"($ID)"}"}}{[% Data.$1 | Localize("TimeLong") %]}smxg;
+    $Content =~ s{\$TimeLong{"\$Q?Data{"($ID)"}"}}{[% Data.$1 | Localize("TimeLong") %]}smxg;
 
     # $TimeShort
-    $Content =~ s{\$TimeShort[{]"\$Q?Data[{]"($ID)"}"}}{[% Data.$1 | Localize("TimeShort") %]}smxg;
+    $Content =~ s{\$TimeShort{"\$Q?Data{"($ID)"}"}}{[% Data.$1 | Localize("TimeShort") %]}smxg;
 
     # $Date
-    $Content =~ s{\$Date[{]"\$Q?Data[{]"($ID)"}"}}{[% Data.$1 | Localize("Date") %]}smxg;
+    $Content =~ s{\$Date{"\$Q?Data{"($ID)"}"}}{[% Data.$1 | Localize("Date") %]}smxg;
 
     # $QData with length
     $Content =~ s{
-            \$QData[{]"($ID)",\s*"(\d+)"}
+            \$QData{"($ID)",\s*"(\d+)"}
         }
         {
             "[% Data." . $SafeArrrayAccess->($1) . " | truncate($2) | html %]"
@@ -620,7 +748,7 @@ sub MigrateDTLtoTT {
 
     # simple $QData
     $Content =~ s{
-            \$QData[{]"($ID)"}
+            \$QData{"($ID)"}
         }
         {
             "[% Data." . $SafeArrrayAccess->($1) . " | html %]"
@@ -628,7 +756,7 @@ sub MigrateDTLtoTT {
 
     # $LQData
     $Content =~ s{
-            \$LQData[{]"($ID)"}
+            \$LQData{"($ID)"}
         }
         {
             "[% Data." . $SafeArrrayAccess->($1) . " | uri %]"
@@ -636,20 +764,20 @@ sub MigrateDTLtoTT {
 
     # simple $Data
     $Content =~ s{
-            \$Data[{]"($ID)"}
+            \$Data{"($ID)"}
         }
         {
             "[% Data." . $SafeArrrayAccess->($1) . " %]"
         }esmxg;
 
     # $Config
-    $Content =~ s{\$Config[{]"($ID)"}}{[% Config("$1") %]}smxg;
+    $Content =~ s{\$Config{"($ID)"}}{[% Config("$1") %]}smxg;
 
     # $Env
-    $Content =~ s{\$Env[{]"($ID)"}}{[% Env("$1") %]}smxg;
+    $Content =~ s{\$Env{"($ID)"}}{[% Env("$1") %]}smxg;
 
     # $QEnv
-    $Content =~ s{\$QEnv[{]"($ID)"}}{[% Env("$1") | html %]}smxg;
+    $Content =~ s{\$QEnv{"($ID)"}}{[% Env("$1") | html %]}smxg;
 
     # dtl:block
     my %BlockSeen;
@@ -675,7 +803,7 @@ sub MigrateDTLtoTT {
         =~ s{<!--\s*dtl:js_on_document_complete_placeholder\s*-->}{[% PROCESS JSOnDocumentCompleteInsert %]}smxg;
 
     # $Include
-    $Content =~ s{\$Include[{]"($ID)"}}{[% InsertTemplate("$1.tt") %]}smxg;
+    $Content =~ s{\$Include{"($ID)"}}{[% InsertTemplate("$1.tt") %]}smxg;
 
     my ( $Counter, $ErrorMessage );
     LINE:
@@ -695,12 +823,14 @@ sub MigrateDTLtoTT {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
