@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +11,11 @@ package Kernel::System::PostMaster::Filter::FollowUpArticleTypeCheck;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -18,12 +23,8 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    $Self->{Debug} = $Param{Debug} || 0;
-
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject MainObject TicketObject ParserObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
+    # get parser object
+    $Self->{ParserObject} = $Param{ParserObject} || die "Got no ParserObject!";
 
     return $Self;
 }
@@ -31,10 +32,13 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    # FollowUpArticleTypeCheck is not needed if there is no TicketID.
+    return 1 if !$Param{TicketID};
+
     # check needed stuff
-    for (qw(TicketID JobConfig GetParam)) {
+    for (qw(JobConfig GetParam)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -54,8 +58,11 @@ sub Run {
         return 1;
     }
 
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
     # Get all articles.
-    my @ArticleIndex = $Self->{TicketObject}->ArticleGet(
+    my @ArticleIndex = $TicketObject->ArticleGet(
         TicketID      => $Param{TicketID},
         DynamicFields => 0,
     );
@@ -68,16 +75,17 @@ sub Run {
 
     # check if current sender got an internal forward
     my $InternalForward;
+    ARTICLE:
     for my $Article ( reverse @ArticleIndex ) {
 
         # just check agent sent article
-        next if $Article->{SenderType} ne 'agent';
+        next ARTICLE if $Article->{SenderType} ne 'agent';
 
         # just check email-internal
-        next if $Article->{ArticleType} ne 'email-internal';
+        next ARTICLE if $Article->{ArticleType} ne 'email-internal';
 
         # check recipients
-        next if !$Article->{To};
+        next ARTICLE if !$Article->{To};
 
         my @ToEmailAddresses = $Self->{ParserObject}->SplitAddressLine(
             Line => $Article->{To},
@@ -87,46 +95,24 @@ sub Run {
         );
         my @EmailAdresses = ( @ToEmailAddresses, @CcEmailAddresses );
 
+        EMAIL:
         for my $Email (@EmailAdresses) {
             my $Recipient = $Self->{ParserObject}->GetEmailAddress(
                 Email => $Email,
             );
             if ( lc $Recipient eq lc $Param{GetParam}->{'X-Sender'} ) {
                 $InternalForward = 1;
-                last;
+                last EMAIL;
             }
         }
     }
     return 1 if !$InternalForward;
 
-    # get latest customer article (current arrival)
-    my $ArticleID;
-    for my $Article ( reverse @ArticleIndex ) {
-        next if $Article->{SenderType} ne 'customer';
-        $ArticleID = $Article->{ArticleID};
-        last;
-    }
-    return 1 if !$ArticleID;
+    # set 'X-OTRS-FollowUp-ArticleType to 'email-internal'
+    $Param{GetParam}->{'X-OTRS-FollowUp-ArticleType'} = $Param{JobConfig}->{ArticleType} || 'email-internal';
 
-    # set article type to email-internal
-    my $ArticleType = $Param{JobConfig}->{ArticleType} || 'email-internal';
-    $Self->{TicketObject}->ArticleUpdate(
-        ArticleID => $ArticleID,
-        Key       => 'ArticleType',
-        Value     => $ArticleType,
-        UserID    => 1,
-        TicketID  => $Param{TicketID},
-    );
-
-    # set sender type to agent/customer
-    my $SenderType = $Param{JobConfig}->{SenderType} || 'customer';
-    $Self->{TicketObject}->ArticleUpdate(
-        ArticleID => $ArticleID,
-        Key       => 'SenderType',
-        Value     => $SenderType,
-        UserID    => 1,
-        TicketID  => $Param{TicketID},
-    );
+    # set 'X-OTRS-FollowUp-SenderType to 'customer'
+    $Param{GetParam}->{'X-OTRS-FollowUp-SenderType'} = $Param{JobConfig}->{SenderType} || 'customer';
 
     return 1;
 }
