@@ -1,6 +1,5 @@
 # --
-# Kernel/System/SearchProfile.pm - module to manage search profiles
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,8 +11,11 @@ package Kernel::System::SearchProfile;
 use strict;
 use warnings;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.22 $) [1];
+our @ObjectDependencies = (
+    'Kernel::System::Cache',
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+);
 
 =head1 NAME
 
@@ -31,39 +33,11 @@ module with all functions to manage search profiles
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::SearchProfile;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $SearchProfileObject = Kernel::System::SearchProfile->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $SearchProfileObject = $Kernel::OM->Get('Kernel::System::SearchProfile');
 
 =cut
 
@@ -74,14 +48,14 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(DBObject ConfigObject LogObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
+    $Self->{DBObject} = $Kernel::OM->Get('Kernel::System::DB');
+
+    $Self->{CacheType} = 'SearchProfile';
+    $Self->{CacheTTL}  = 60 * 60 * 24 * 20;
 
     # set lower if database is case sensitive
     $Self->{Lower} = '';
-    if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+    if ( $Self->{DBObject}->GetDatabaseFunction('CaseSensitive') ) {
         $Self->{Lower} = 'LOWER';
     }
 
@@ -108,7 +82,10 @@ sub SearchProfileAdd {
     # check needed stuff
     for (qw(Base Name Key UserLogin)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -132,21 +109,34 @@ sub SearchProfileAdd {
     for my $Value (@Data) {
 
         return if !$Self->{DBObject}->Do(
-            SQL => 'INSERT INTO search_profile'
-                . ' (login, profile_name,  profile_type, profile_key, profile_value)'
-                . ' VALUES (?, ?, ?, ?, ?) ',
+            SQL => "
+                INSERT INTO search_profile
+                (login, profile_name,  profile_type, profile_key, profile_value)
+                VALUES (?, ?, ?, ?, ?)
+                ",
             Bind => [
                 \$Login, \$Param{Name}, \$Param{Type}, \$Param{Key}, \$Value,
             ],
         );
     }
 
+    # reset cache
+    my $CacheKey = $Login . '::' . $Param{Name};
+    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+        Type => $Self->{CacheType},
+        Key  => $Login,
+    );
+    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
+
     return 1;
 }
 
 =item SearchProfileGet()
 
-returns a hash with search profile
+returns hash with search profile.
 
     my %SearchProfileData = $SearchProfileObject->SearchProfileGet(
         Base      => 'TicketSearch',
@@ -162,7 +152,10 @@ sub SearchProfileGet {
     # check needed stuff
     for (qw(Base Name UserLogin)) {
         if ( !defined( $Param{$_} ) ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -170,10 +163,22 @@ sub SearchProfileGet {
     # create login string
     my $Login = $Param{Base} . '::' . $Param{UserLogin};
 
-    # get searech profile
+    # check the cache
+    my $CacheKey = $Login . '::' . $Param{Name};
+    my $Cache    = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
+    return %{$Cache} if $Cache;
+
+    # get search profile
     return if !$Self->{DBObject}->Prepare(
-        SQL => "SELECT profile_type, profile_key, profile_value FROM "
-            . "search_profile WHERE profile_name = ? AND $Self->{Lower}(login) = $Self->{Lower}(?)",
+        SQL => "
+            SELECT profile_type, profile_key, profile_value
+            FROM search_profile
+            WHERE profile_name = ?
+                AND $Self->{Lower}(login) = $Self->{Lower}(?)
+            ",
         Bind => [ \$Param{Name}, \$Login ],
     );
 
@@ -186,13 +191,19 @@ sub SearchProfileGet {
             $Result{ $Data[1] } = $Data[2];
         }
     }
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
+        Key   => $CacheKey,
+        Value => \%Result
+    );
 
     return %Result;
 }
 
 =item SearchProfileDelete()
 
-deletes an profile
+deletes a search profile.
 
     $SearchProfileObject->SearchProfileDelete(
         Base      => 'TicketSearch',
@@ -208,7 +219,10 @@ sub SearchProfileDelete {
     # check needed stuff
     for (qw(Base Name UserLogin)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -217,16 +231,32 @@ sub SearchProfileDelete {
     my $Login = $Param{Base} . '::' . $Param{UserLogin};
 
     # delete search profile
-    return $Self->{DBObject}->Do(
-        SQL => "DELETE FROM search_profile WHERE "
-            . " profile_name = ? AND $Self->{Lower}(login) = $Self->{Lower}(?)",
+    return if !$Self->{DBObject}->Do(
+        SQL => "
+            DELETE
+            FROM search_profile
+            WHERE profile_name = ?
+                AND $Self->{Lower}(login) = $Self->{Lower}(?)
+            ",
         Bind => [ \$Param{Name}, \$Login ],
     );
+
+    # delete cache
+    my $CacheKey = $Login . '::' . $Param{Name};
+    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+        Type => $Self->{CacheType},
+        Key  => $Login,
+    );
+    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
+    return 1;
 }
 
 =item SearchProfileList()
 
-returns a hash of all proviles
+returns a hash of all profiles for the given user.
 
     my %SearchProfiles = $SearchProfileObject->SearchProfileList(
         Base      => 'TicketSearch',
@@ -241,7 +271,10 @@ sub SearchProfileList {
     # check needed stuff
     for (qw(Base UserLogin)) {
         if ( !defined( $Param{$_} ) ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -249,10 +282,19 @@ sub SearchProfileList {
     # create login string
     my $Login = $Param{Base} . '::' . $Param{UserLogin};
 
+    my $Cache = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $Login,
+    );
+    return %{$Cache} if $Cache;
+
     # get search profile list
     return if !$Self->{DBObject}->Prepare(
-        SQL =>
-            "SELECT profile_name FROM search_profile WHERE $Self->{Lower}(login) = $Self->{Lower}(?)",
+        SQL => "
+            SELECT profile_name
+            FROM search_profile
+            WHERE $Self->{Lower}(login) = $Self->{Lower}(?)
+            ",
         Bind => [ \$Login ],
     );
 
@@ -261,7 +303,12 @@ sub SearchProfileList {
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
         $Result{ $Data[0] } = $Data[0];
     }
-
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
+        Key   => $Login,
+        Value => \%Result,
+    );
     return %Result;
 }
 
@@ -278,9 +325,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.22 $ $Date: 2012-11-20 15:37:54 $
-
-=cut
