@@ -1243,9 +1243,10 @@ sub GetStatTable {
         for my $Attribute ( @{$SortedAttributesRef} ) {
             next ATTRIBUTE if !$TicketAttributes{$Attribute};
 
-            if ( $Attribute =~ /Owner|Responsible/ ) {
+            if ( $Attribute eq 'Owner' || $Attribute eq 'Responsible' ) {
                 $Ticket{$Attribute} = $Kernel::OM->Get('Kernel::System::User')->UserName(
-                    User => $Ticket{$Attribute},
+                    User          => $Ticket{$Attribute},
+                    NoOutOfOffice => 1,
                 );
             }
 
