@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::SupportDataCollector::Plugin::Database::mysql::MaxAllowedPacket;
@@ -11,16 +11,14 @@ package Kernel::System::SupportDataCollector::Plugin::Database::mysql::MaxAllowe
 use strict;
 use warnings;
 
-use parent qw(Kernel::System::SupportDataCollector::PluginBase);
-
-use Kernel::Language qw(Translatable);
+use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
 our @ObjectDependencies = (
     'Kernel::System::DB',
 );
 
 sub GetDisplayPath {
-    return Translatable('Database');
+    return 'Database';
 }
 
 sub Run {
@@ -38,19 +36,19 @@ sub Run {
 
         if (
             !$Row[1]
-            || $Row[1] < 1024 * 1024 * 64
+            || $Row[1] < 1024 * 1024 * 20
             )
         {
             $Self->AddResultProblem(
-                Label => Translatable('Maximum Query Size'),
+                Label => 'Maximum Query Size',
                 Value => $Row[1] / 1024 / 1024 . ' MB',
                 Message =>
-                    Translatable("The setting 'max_allowed_packet' must be higher than 64 MB."),
+                    "The setting 'max_allowed_packet' must be higher than 20 MB.",
             );
         }
         else {
             $Self->AddResultOk(
-                Label => Translatable('Maximum Query Size'),
+                Label => 'Maximum Query Size',
                 Value => $Row[1] / 1024 / 1024 . ' MB',
             );
         }
@@ -59,4 +57,16 @@ sub Run {
     return $Self->GetResults();
 }
 
+=back
+
+=head1 TERMS AND CONDITIONS
+
+This software is part of the OTRS project (L<http://otrs.org/>).
+
+This software comes with ABSOLUTELY NO WARRANTY. For details, see
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=cut
+
 1;
