@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::SupportDataCollector::Plugin::OTRS::Ticket::StaticDBOrphanedRecords;
@@ -11,9 +11,7 @@ package Kernel::System::SupportDataCollector::Plugin::OTRS::Ticket::StaticDBOrph
 use strict;
 use warnings;
 
-use parent qw(Kernel::System::SupportDataCollector::PluginBase);
-
-use Kernel::Language qw(Translatable);
+use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -21,7 +19,7 @@ our @ObjectDependencies = (
 );
 
 sub GetDisplayPath {
-    return Translatable('OTRS');
+    return 'OTRS';
 }
 
 sub Run {
@@ -44,18 +42,16 @@ sub Run {
         if ($OrphanedTicketLockIndex) {
             $Self->AddResultWarning(
                 Identifier => 'TicketLockIndex',
-                Label      => Translatable('Orphaned Records In ticket_lock_index Table'),
+                Label      => 'Orphaned Records In ticket_lock_index Table',
                 Value      => $OrphanedTicketLockIndex,
                 Message =>
-                    Translatable(
-                    'Table ticket_lock_index contains orphaned records. Please run bin/otrs.Console.pl "Maint::Ticket::QueueIndexCleanup" to clean the StaticDB index.'
-                    ),
+                    'Table ticket_lock_index contains orphaned records. Please run otrs/bin/otrs.CleanTicketIndex.pl to clean the StaticDB index.',
             );
         }
         else {
             $Self->AddResultOk(
                 Identifier => 'TicketLockIndex',
-                Label      => Translatable('Orphaned Records In ticket_lock_index Table'),
+                Label      => 'Orphaned Records In ticket_lock_index Table',
                 Value      => $OrphanedTicketLockIndex || '0',
             );
         }
@@ -68,18 +64,16 @@ sub Run {
         if ($OrphanedTicketLockIndex) {
             $Self->AddResultWarning(
                 Identifier => 'TicketIndex',
-                Label      => Translatable('Orphaned Records In ticket_index Table'),
+                Label      => 'Orphaned Records In ticket_index Table',
                 Value      => $OrphanedTicketIndex,
                 Message =>
-                    Translatable(
-                    'Table ticket_index contains orphaned records. Please run bin/otrs.Console.pl "Maint::Ticket::QueueIndexCleanup" to clean the StaticDB index.'
-                    ),
+                    'Table ticket_index contains orphaned records. Please run otrs/bin/otrs.CleanTicketIndex.pl to clean the StaticDB index.',
             );
         }
         else {
             $Self->AddResultOk(
                 Identifier => 'TicketIndex',
-                Label      => Translatable('Orphaned Records In ticket_index Table'),
+                Label      => 'Orphaned Records In ticket_index Table',
                 Value      => $OrphanedTicketIndex || '0',
             );
         }
@@ -88,4 +82,16 @@ sub Run {
     return $Self->GetResults();
 }
 
+=back
+
+=head1 TERMS AND CONDITIONS
+
+This software is part of the OTRS project (L<http://otrs.org/>).
+
+This software comes with ABSOLUTELY NO WARRANTY. For details, see
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=cut
+
 1;
