@@ -1,6 +1,5 @@
 # --
-# Kernel/System/Time.pm - time functions
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -374,9 +373,8 @@ sub MailTimeStamp {
 
     # According to RFC 2822, section 3.3
 
-    # ---
     # The date and time-of-day SHOULD express local time.
-
+    #
     # The zone specifies the offset from Coordinated Universal Time (UTC,
     # formerly referred to as "Greenwich Mean Time") that the date and
     # time-of-day represent.  The "+" or "-" indicates whether the
@@ -391,7 +389,6 @@ sub MailTimeStamp {
     # in a local time zone other than Universal Time and therefore
     # indicates that the date-time contains no information about the local
     # time zone.
-    # ---
 
     my @DayMap   = qw/Sun Mon Tue Wed Thu Fri Sat/;
     my @MonthMap = qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
@@ -715,8 +712,8 @@ sub DestinationTime {
 
                 # Check if we have a working hour
                 if ( grep { $H == $_ } @{ $TimeWorkingHours->{ $LDay{$WDay} } } ) {
-                    if ( $Param{Time} > 60 * 60 ) {
-                        my $RestOfHour = 3600 - ( $Minute * 60 + $Second );
+                    my $RestOfHour = 3600 - ( $Minute * 60 + $Second );
+                    if ( $Param{Time} > $RestOfHour ) {
                         $DestinationTime += $RestOfHour;
                         $Param{Time} -= $RestOfHour;
                     }
