@@ -1,6 +1,5 @@
 // --
-// Core.Form.js - provides functions for form handling
-// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -57,8 +56,6 @@ Core.Form = (function (TargetNS) {
             $Form
                 .find("input:not([type='hidden']), textarea, select")
                 .attr('readonly', 'readonly')
-                // trigger custom "readonly" event for Core.UI.IE7Fixes
-                .trigger('readonly')
                 .end()
                 .find('button')
                 .attr('disabled', 'disabled');
@@ -85,8 +82,6 @@ Core.Form = (function (TargetNS) {
         $Form
             .find("input:not([type=hidden]), textarea, select")
             .removeAttr('readonly')
-            // trigger custom "readonly" event for Core.UI.IE7Fixes
-            .trigger('readonly')
             .end()
             .find('button')
             .removeAttr('disabled');
@@ -124,7 +119,7 @@ Core.Form = (function (TargetNS) {
         if (isJQueryObject($ClickedBox, $SelectAllCheckbox)) {
             var ElementName = $ClickedBox.attr('name'),
                 SelectAllID = $SelectAllCheckbox.attr('id'),
-                $Elements = $('input:checkbox[name=' + ElementName + ']').filter('[id!=' + SelectAllID + ']'),
+                $Elements = $('input[type="checkbox"][name=' + ElementName + ']').filter('[id!=' + SelectAllID + ']:visible'),
                 Status = $ClickedBox.prop('checked'),
                 CountCheckboxes,
                 CountSelectedCheckboxes;
@@ -138,7 +133,7 @@ Core.Form = (function (TargetNS) {
                     $SelectAllCheckbox.prop('checked', true);
                 }
                 else {
-                    $SelectAllCheckbox.removeAttr('checked');
+                    $SelectAllCheckbox.prop('checked', false);
                 }
             }
         }
@@ -148,34 +143,30 @@ Core.Form = (function (TargetNS) {
      * @function
      * @description
      *      This function marks the "SelectAll checkbox" as checked if all depending checkboxes are already marked checked.
+     *      Adds PubSub event to control handling of checkboxes, if a filter is used
      * @param {jQueryObject} $Checkboxes The jquery object with all dependent checkboxes
      * @param {jQueryObject} $SelectAllCheckbox The object with the SelectAll checkbox
      * @return nothing
      */
     TargetNS.InitSelectAllCheckboxes = function ($Checkboxes, $SelectAllCheckbox) {
         if (isJQueryObject($Checkboxes, $SelectAllCheckbox)) {
+            // Mark SelectAll checkbox if all depending checkboxes are already marked on initialization
             if ($Checkboxes.filter('[id!=' + $SelectAllCheckbox.attr('id') + ']').length === $Checkboxes.filter(':checked').length) {
                 $SelectAllCheckbox.prop('checked', true);
             }
+
+            // Remove checkbox selection, if filter is used/changed
+            Core.App.Subscribe('Event.UI.Table.InitTableFilter.Change', function ($FilterInput, $Container, ColumnNumber) {
+                // Only continue, if the filter event is associated with the container we are working in
+                if (!$.contains($Container[0], $SelectAllCheckbox[0])) {
+                    return false;
+                }
+
+                $Checkboxes.prop('checked', false);
+                $SelectAllCheckbox.prop('checked', false);
+            });
         }
     };
 
-    TargetNS.HideSelectAllCheckboxes = function($ContainerElement, SelectAllSelector) {
-        Core.App.Subscribe('Event.UI.Table.InitTableFilter.Change', function ($FilterInput, $Container, ColumnNumber) {
-            // Only execute code, if the fired filter event is associated with the container we want to handle
-            if ($ContainerElement.selector !== $Container.selector) {
-                return false;
-            }
-
-            // Filter is set, remove checkbox to select all entries
-            if ($FilterInput.val().length) {
-                $(SelectAllSelector).addClass('Invisible');
-            }
-            else {
-                $(SelectAllSelector).removeClass('Invisible');
-            }
-        });
-    };
-
     return TargetNS;
 }(Core.Form || {}));
